@@ -33,7 +33,7 @@ int beast2_main_corev4()   {
 	const BEAST2_OPTIONS_PTR	opt=GLOBAL_OPTIONS;
 	const BEAST2_EXTRA          extra=opt->extra;
 	typedef int QINT;
-	const   QINT  q=1L;
+	const QINT  q=opt->io.q;
 	CI_PARAM     ciParam={0,};
 	CI_RESULT    ci[MAX_NUM_BASIS];
 	if (extra.computeCredible) {
@@ -145,14 +145,16 @@ int beast2_main_corev4()   {
 			{   
 				GenarateRandomBasis(MODEL.b,MODEL.NUMBASIS,N,&RND);
 				if (q > 1) {
-					MODEL.b[0].numKnot=0;
+					MODEL.b[0].nKnot=0;
 					MODEL.b[0].KNOT[0]=N+1;
-					MODEL.b[0].ORDER[0]=3;
+					MODEL.b[0].ORDER[0]=MODEL.b[0].prior.minOrder;
 					MODEL.b[0].CalcBasisKsKeK_TermType(&MODEL.b[0]);
-					MODEL.b[1].numKnot=0;
-					MODEL.b[1].KNOT[0]=N+1;
-					MODEL.b[1].ORDER[0]=1;
-					MODEL.b[1].CalcBasisKsKeK_TermType(&MODEL.b[1]);
+					if (MODEL.NUMBASIS >=2) {
+						MODEL.b[1].nKnot=0;
+						MODEL.b[1].KNOT[0]=N+1;
+						MODEL.b[1].ORDER[0]=MODEL.b[0].prior.minOrder;
+						MODEL.b[1].CalcBasisKsKeK_TermType(&MODEL.b[1]);
+					}
 				}
 				MODEL.b[0].Kbase=0;                           
 				UpdateBasisKbase(MODEL.b,MODEL.NUMBASIS,0);	
@@ -191,7 +193,7 @@ int beast2_main_corev4()   {
 				basis->Propose(basis,&NEW,&PROPINFO); 
 				#ifdef __DEBUG__
 					I32 basisIdx=basis - MODEL.b;
-					if (basisIdx==0 && (NEW.flagMoveType==BIRTH||NEW.flagMoveType==MOVE)) {
+					if (basisIdx==0 && (NEW.jumpType==BIRTH||NEW.jumpType==MOVE)) {
 						flagSat[NEW.newKnot - 1]+=1;
 					}
 				#endif
@@ -202,7 +204,7 @@ int beast2_main_corev4()   {
 					Knewterm+=kterms;
 				} 
 				#ifdef SOLARIS_COMPILER
-					NEW.k1=NEW.k1_old;
+					NEW.k1=NEW.k1_new=NEW.k1_old;
 				#endif
 				NEW.k2_new=NEW.k1+Knewterm - 1L;	
 				NEW.k1+=basis->Kbase;			
@@ -276,7 +278,9 @@ int beast2_main_corev4()   {
 						   precFunc.GetXtXPrecDiag(&MODEL);
 						   precFunc.chol_addCol(MODEL.curr.XtX,MODEL.curr.cholXtX,MODEL.curr.precXtXDiag,MODEL.curr.K,1L,MODEL.curr.K);
 						   precFunc.ComputeMargLik(&MODEL.curr,&MODEL,&yInfo,&hyperPar);
-						   //r_printf("prec:%.4f|marg_lik_prop:%.4f|marg_like_curr:%.4f \n",MODEL.precVal,MODEL.prop.marg_lik,MODEL.curr.marg_lik);
+						   #if !(defined(R_RELEASE)||defined(M_RELEASE))
+						   r_printf("prec: %.4f|marg_lik_prop: %.4f|marg_like_curr: %.4f \n",MODEL.precVal,MODEL.prop.marg_lik,MODEL.curr.marg_lik);
+						   #endif
 						   continue;
 					   }  else {
 						   skipCurrentPixel=2;
@@ -290,7 +294,7 @@ int beast2_main_corev4()   {
 				   }
 				}
 				F32  factor;				
-				if   ( NEW.flagMoveType==MOVE||basis->type==OUTLIERID) 	factor=0.;
+				if   ( NEW.jumpType==MOVE||basis->type==OUTLIERID) 	factor=0.;
 				else { factor=basis->ModelPrior(basis,&NEW,N); }
 				F32 delta_lik=MODEL.prop.marg_lik - MODEL.curr.marg_lik+factor;
 				I08     acceptTheProposal;
@@ -303,14 +307,14 @@ int beast2_main_corev4()   {
 					else						acceptTheProposal=*(RND.rnd32)++< expValue * 4.294967296e+09;
 				}
 				#ifdef __DEBUG__
-					if (basisIdx==0)++(flagS[NEW.flagMoveType]);
-					else++(flagT[NEW.flagMoveType]);
+					if (basisIdx==0)++(flagS[NEW.jumpType]);
+					else++(flagT[NEW.jumpType]);
 				#endif
 				if(acceptTheProposal)
 				{
 					#ifdef __DEBUG__
-						if (basisIdx==0)++(accS[NEW.flagMoveType]);
-						else++(accT[NEW.flagMoveType]);
+						if (basisIdx==0)++(accS[NEW.jumpType]);
+						else++(accT[NEW.jumpType]);
 					#endif
 					if (yInfo.nMissing > 0 && Knewterm > 0 )  
 						f32_mat_multirows_set_by_submat(Xnewterm,Npad,Knewterm,Xt_zeroBackup,yInfo.rowsMissing,yInfo.nMissing);
@@ -379,7 +383,7 @@ int beast2_main_corev4()   {
 					if (ite%10==0) {
 						 float sum=0;
 						 int   n=0;
-							r_printf("ite%d: ",ite);
+							r_printf("ite %d: ",ite);
 							for (int i=1; i <=MODEL.nPrec; i++) {
 								if (opt->prior.precPriorType < 2) {
 									sum+=MODEL.precVal;
@@ -401,7 +405,9 @@ int beast2_main_corev4()   {
 						precFunc.ComputeMargLik( &MODEL.curr,&MODEL,&yInfo,&hyperPar);
 					} while (  IsNaN(MODEL.curr.marg_lik) && ntries < 20 );
 					if ( IsNaN(MODEL.curr.marg_lik) ) {
-						//r_printf("skip3|prec:%.4f|marg_lik_cur:%.4f \n",MODEL.precVal,MODEL.curr.marg_lik);
+						#if !(defined(R_RELEASE)||defined(M_RELEASE))
+						r_printf("skip3|prec: %.4f|marg_lik_cur: %.4f \n",MODEL.precVal,MODEL.curr.marg_lik);
+						#endif
 						skipCurrentPixel=3;
 						break;
 					} 
@@ -444,13 +450,13 @@ int beast2_main_corev4()   {
 					{
 						BEAST2_BASIS_PTR  basis=MODEL.b+i;
 						CORESULT        * result=coreResults+i;
-						I32        numKnot=basis->numKnot;
+						I32        nKnot=basis->nKnot;
 						TKNOT_PTR  KNOT=basis->KNOT;
-						result->xNProb[numKnot]+=1L;
-						for (I32 i=0; i < numKnot; i++) result->xProb[ KNOT[i]-1 ]+=1L;
+						result->xNProb[nKnot]+=1L;
+						for (I32 i=0; i < nKnot; i++) result->xProb[ KNOT[i]-1 ]+=1L;
 						if (result->xorder !=NULL) {
 							TORDER_PTR  orderList=basis->ORDER;
-							for (I32 i=0; i <=numKnot;++i) {
+							for (I32 i=0; i <=nKnot;++i) {
 								I16 r1=KNOT[i-1],r2=KNOT[i]-1;
 								r_ippsAddC_32s_ISfs(orderList[i],result->xorder+r1 - 1,r2 - r1+1,0);							
 							}
@@ -475,7 +481,7 @@ int beast2_main_corev4()   {
 					F32PTR           MEMBUF1=Xnewterm+3*Npad;
 					F32PTR           MEMBUF2=MODEL.prop.beta_mean; 
 					BEAST2_BASIS_PTR basis=&MODEL.b[MODEL.sid];
-					I32             knotNum=basis->numKnot;
+					I32             knotNum=basis->nKnot;
 					TKNOT_PTR       knotList=basis->KNOT;
 					F32PTR       beta=BETA;
 					TORDER_PTR   orderList=basis->ORDER;
@@ -515,7 +521,7 @@ int beast2_main_corev4()   {
 				if(extra.computeTrendSlope)
 				{
 					BEAST2_BASIS_PTR basis=&MODEL.b[MODEL.tid];
-					I32             knotNum=basis->numKnot;
+					I32             knotNum=basis->nKnot;
 					TKNOT_PTR       knotList=basis->KNOT;
 					F32PTR TREND=Xnewterm+Npad * MODEL.tid;     
 					F32PTR SLP=Xnewterm+3 * Npad;				
@@ -550,7 +556,7 @@ int beast2_main_corev4()   {
 				if(extra.tallyPosNegOutliers)
 				{
 					BEAST2_BASIS_PTR basis=&MODEL.b[MODEL.oid];
-					rI32             knotNum=basis->numKnot;
+					rI32             knotNum=basis->nKnot;
 					rTKNOT_PTR       knotList=basis->KNOT;
 					const F32PTR OUTLIIER=Xnewterm+Npad* MODEL.oid;
 					I32  posKnotNum=0;
@@ -924,7 +930,7 @@ int beast2_main_corev4()   {
 					result.oneg_cpOccPr,result.oneg_cp,result.oneg_cpPr,result.oneg_cpCI);
 			}
 		}
-		if (opt->extra.dumpInputData||!skipCurrentPixel) {	
+		if ( !skipCurrentPixel) {	
 			I32  N=opt->io.N;	
 			I32  Nq=N * q;  
 			for (int i=0; i < q;++i) {
@@ -947,7 +953,7 @@ int beast2_main_corev4()   {
 			I08 hasSeasonCmpnt=opt->prior.basisType[0]==SEASONID||opt->prior.basisType[0]==DUMMYID||opt->prior.basisType[0]==SVDID;
 			I08 hasOutlierCmpnt=opt->prior.basisType[opt->prior.numBasis - 1]==OUTLIERID;
 			I08 hasTrendCmpnt=1;
-			F32PTR BUF=Xnewterm+Nq;
+			F32PTR BUF=yInfo.Y;
 			f32_fill_val(0.,BUF,Nq);
 			if (hasTrendCmpnt)   f32_add_vec_inplace(result.tY,BUF,Nq);
 			if (hasSeasonCmpnt)  f32_add_vec_inplace(result.sY,BUF,Nq);
